@@ -1,14 +1,16 @@
 import subprocess
 import fractions
 import os
+import traceback
 
+from xenonmkv.utils.text import REFERENCE_FRAMES_INFO
 from xenonmkv.utils.reference_frame import ReferenceFrameValidator
 from xenonmkv.utils.mkv_info_parser import MKVInfoParser
 from xenonmkv.utils.process_handler import ProcessHandler
 from xenonmkv.utils.track import MKVTrack, AudioTrack, VideoTrack, UnsupportedCodecError
 
 
-class MKVFile():
+class MKVFile:
     path = ""
     tracks = {}
     duration = 0
@@ -27,14 +29,24 @@ class MKVFile():
 
     # Open the mkvinfo process and parse its output.
     def get_mkvinfo(self):
-        mkvinfo_args = [self.args.tool_paths["mkvinfo"], "--ui-language", "en_US", self.get_path()]
-        self.log.debug("Executing 'mkvinfo {0}'".format(' '.join(mkvinfo_args)))
+        mkvinfo_args = [self.args.tool_paths["mkvinfo"]]
+
+        # Language code can either be 'en' or 'en_US' depending on platform. 
+        # This ensures that the output of this tool can be parsed.
+        # Default 'en_US' depending for Linux
+        language_code = 'en_US'
+        if language_code:
+            mkvinfo_args.append("--ui-language")
+            mkvinfo_args.append(language_code)
+
+        mkvinfo_args.append(self.get_path())
+        self.log.debug("Executing '{0}'".format(' '.join(mkvinfo_args)))
         try:
-            # Force mkvinfo to output details in English; corrected version of pull request 
-            # <https://github.com/jbillo/xenonmkv/pull/14>
-            result = subprocess.check_output(mkvinfo_args)
-        except subprocess.CalledProcessError as e:
-            self.log.debug("mkvinfo process error: {0}".format(e.output))
+            result = subprocess.check_output(mkvinfo_args, shell=False, bufsize=0,
+                                             close_fds=True, stderr=subprocess.PIPE,
+                                             universal_newlines=True)
+        except subprocess.CalledProcessError:
+            self.log.debug("mkvinfo process error: {0}".format(traceback.print_exc()))
             raise Exception("Error occurred while obtaining MKV information "
                             "for {0} - please make sure the file exists, is readable and "
                             "a valid MKV file".format(self.get_path()))
@@ -82,7 +94,7 @@ class MKVFile():
     # Return a float value specifying the display aspect ratio.
     def parse_display_aspect_ratio(self, dar_string):
         self.log.debug("Attempting to parse display aspect ratio '{0}'".format(
-                       dar_string))
+            dar_string))
         if "16/9" in dar_string:
             return 1.778
         elif "4/3" in dar_string:
@@ -96,7 +108,7 @@ class MKVFile():
             except:
                 # Couldn't divide
                 raise Exception("Could not parse display aspect ratio of {0}".format(
-                                dar_string))
+                    dar_string))
         else:
             return float(dar_string.strip())
 
@@ -107,7 +119,7 @@ class MKVFile():
         t_width = track.width
         gcd = fractions.gcd(t_height, t_width)
         self.log.debug("GCD of {0} height, {1} width is {2:f}".format(
-                       t_height, t_width, gcd))
+            t_height, t_width, gcd))
 
         if gcd == 0:
             # Pixel aspect ratio should be 1:1
@@ -127,7 +139,7 @@ class MKVFile():
             t_width = t_width / 10
 
         self.log.debug("Calculated pixel aspect ratio is {0:f}:{1:f} ({2:f})".format(
-                       t_height, t_width, t_height / t_width))
+            t_height, t_width, t_height / t_width))
 
         if not self.args.no_round_par:
             if t_height / t_width > 0.98 and t_height / t_width < 1:
@@ -158,7 +170,7 @@ class MKVFile():
         audio_duration = audio_duration[0:audio_duration.index("s")]
 
         self.log.debug("Audio duration detected as {0} seconds".format(
-                       audio_duration))
+            audio_duration))
 
         # Check if there is a decimal value; if so, add one second
         if "." in audio_duration:
@@ -216,7 +228,7 @@ class MKVFile():
             )
             self.log.debug("Track {0} will use ID {1} when taking actions "
                            "with the mkvtoolnix suite".format(
-                           track_number, track_mkvtoolnix_id))
+                track_number, track_mkvtoolnix_id))
 
             # Set individual track properties for the object by track ID
             if track_type in ("video", "audio"):
@@ -230,6 +242,8 @@ class MKVFile():
 
                 track.height = int(mediainfo_track[0])
                 track.width = int(mediainfo_track[1])
+                self.log.debug('Track Height: {0}, Track Width: {1}'
+                               .format(str(track.height), str(track.width)))
 
                 try:
                     # Possible condition: no reference frames detected
@@ -242,15 +256,7 @@ class MKVFile():
                                    "frames".format(mediainfo_track[2], track.number))
 
                 track.language = mediainfo_track[3].lower()
-                if mediainfo_track[4]:
-                    track.frame_rate = float(mediainfo_track[4])
-                elif mediainfo_track[7]:
-                    self.log.debug("Using original track frame rate as "
-                                   "container frame rate was not set")
-                    track.frame_rate = float(mediainfo_track[7])
-                else:
-                    raise ValueError("Could not read FPS information "
-                                     "from mediainfo output")
+                self.log.debug('Track Language: {0}'.format(str(track.language)))
 
                 track.codec_id = mediainfo_track[5]
                 track.display_ar = self.parse_display_aspect_ratio(
@@ -259,22 +265,19 @@ class MKVFile():
 
                 self.log.debug("Video track {0} has dimensions {1}x{2} with "
                                "{3} reference frames".format(
-                               track.number, track.width,
-                               track.height, track.reference_frames))
-                self.log.debug("Video track {0} has {1:f} FPS and codec {2}".format(
-                               track.number, track.frame_rate, track.codec_id))
+                    track.number, track.width,
+                    track.height, track.reference_frames))
+                self.log.debug("Video track {0} has codec {1}".format(
+                    track.number, track.codec_id))
                 self.log.debug("Video track {0} has display aspect ratio {1:f}".format(
-                               track.number, track.display_ar))
+                    track.number, track.display_ar))
 
                 if self.reference_frames_exceeded(track):
                     self.log.warning("Video track {0} contains too many "
                                      "reference frames to play properly on low-powered "
                                      "devices. See {1} for details".format(
-                                        track.number, xenonmkv.util.text.REFERENCE_FRAMES_INFO)
-                                    )
-                    if not self.args.ignore_reference_frames:
-                        raise Exception("Video track {0} has too many "
-                                        "reference frames".format(track.number))
+                        track.number, REFERENCE_FRAMES_INFO)
+                    )
                 else:
                     self.log.debug("Video track {0} has a reasonable number "
                                    "of reference frames, and should be compatible with "
@@ -288,7 +291,10 @@ class MKVFile():
 
                 track.codec_id = mediainfo_track[0]
                 track.language = mediainfo_track[1].lower()
-                track.channels = int(mediainfo_track[2])
+                try:
+                    track.channels = int(mediainfo_track[2])
+                except Exception:
+                    track.channels = 2
 
                 # Indicate if the audio track needs a recode.
                 # By default, it does.
@@ -304,27 +310,27 @@ class MKVFile():
                         self.log.info("Audio track {0} will not need to be "
                                       "re-encoded ({1} channels specified, {2} channels "
                                       "in file)".format(track.number,
-                                      self.args.channels, track.channels))
+                                                        self.args.channels, track.channels))
                         track.needs_recode = False
 
                 self.log.debug("Audio track {0} has codec {1} and language {2}".format(
-                               track.number, track.codec_id, track.language))
+                    track.number, track.codec_id, track.language))
                 self.log.debug("Audio track {0} has {1} channel(s)".format(
-                               track.number, track.channels))
+                    track.number, track.channels))
 
             else:
                 # Unrecognized track type. Don't completely abort processing,
                 # but do log it.
                 # Do not proceed to add this to the global tracks list.
                 self.log.debug("Unrecognized track type '{0}' in {1}; skipping".format(
-                               track_type, track_number))
+                    track_type, track_number))
                 continue
 
             # Add general properties to track
             track.mkvtoolnix_id = track_mkvtoolnix_id
 
             self.log.debug("All properties set for {0} track {1}".format(
-                           track_type, track.number))
+                track_type, track.number))
             track.track_type = track_type
             self.tracks[track.number] = track
 
@@ -354,19 +360,19 @@ class MKVFile():
             elif track.track_type == "audio":
                 audio_tracks += 1
 
-        return (video_tracks > 1 or audio_tracks > 1)
+        return video_tracks > 1 or audio_tracks > 1
 
     def set_video_track(self, track_id):
-        if (self.tracks[track_id] and
-                self.tracks[track_id].track_type == "video"):
+        if self.tracks[track_id] \
+                and self.tracks[track_id].track_type == "video":
             self.video_track_id = track_id
         else:
             raise Exception("Video track with ID {0} was not found "
                             "in file".format(track_id))
 
     def set_audio_track(self, track_id):
-        if (self.tracks[track_id] and
-                self.tracks[track_id].track_type == "audio"):
+        if self.tracks[track_id] \
+                and self.tracks[track_id].track_type == "audio":
             self.audio_track_id = track_id
         else:
             raise Exception("Audio track with ID {0} was not found "
@@ -390,14 +396,14 @@ class MKVFile():
             # Completely ignore 'default' track setting
             for track_id in self.tracks:
                 track = self.tracks[track_id]
-                if (track.track_type == "video" and
-                        not self.video_track_id and
-                        track.language == preferred_language):
+                if (track.track_type == "video"
+                    and not self.video_track_id
+                    and track.language == preferred_language):
                     self.video_track_id = track.number
 
-                elif (track.track_type == "audio" and
-                        not self.audio_track_id and
-                        track.language == preferred_language):
+                elif (track.track_type == "audio"
+                      and not self.audio_track_id
+                      and track.language == preferred_language):
                     self.audio_track_id = track.number
 
         # If a track was selected, all subsequent tests
@@ -412,8 +418,8 @@ class MKVFile():
                 self.video_track_id = track.number
 
             elif (track.track_type == "audio" and
-                    track.default and
-                    not self.audio_track_id):
+                      track.default and
+                      not self.audio_track_id):
                 self.audio_track_id = track.number
 
         # Check again if we have tracks specified here.
@@ -429,7 +435,7 @@ class MKVFile():
                     self.video_track_id = track.number
                     self.log.debug(
                         "First available video track in file is {0}".format(
-                        self.video_track_id))
+                            self.video_track_id))
                     break
 
         if not self.audio_track_id:
@@ -440,7 +446,7 @@ class MKVFile():
                 if track.track_type == "audio":
                     self.audio_track_id = track.number
                     self.log.debug("First available audio track in file is {0}".format(
-                                   self.audio_track_id))
+                        self.audio_track_id))
                     break
 
         # If we still don't have a video and audio track specified,
@@ -464,7 +470,7 @@ class MKVFile():
 
             track_list[track.number] = (
                 "{0} - {1} [{2} channels]".format(
-                track.number, track.language, track.channels)
+                    track.number, track.language, track.channels)
             )
 
         return track_list
@@ -478,7 +484,7 @@ class MKVFile():
 
             track_list[track.number] = (
                 "{0} - {1} [{2}x{3}]".format(
-                track.number, track.language, track.width, track.height)
+                    track.number, track.language, track.width, track.height)
             )
 
         return track_list
@@ -496,11 +502,11 @@ class MKVFile():
         mkvtoolnix_audio_id = self.tracks[self.audio_track_id].mkvtoolnix_id
 
         self.log.debug("Using video track from MKV file with ID {0} "
-                       "(mkvtoolnix ID {1})".format(
-                       self.video_track_id, mkvtoolnix_video_id))
+                       "(mkvtoolnix ID {1})"
+                       .format(self.video_track_id, mkvtoolnix_video_id))
         self.log.debug("Using audio track from MKV file with ID {0} "
-                       "(mkvtoolnix ID {1})".format(
-                       self.audio_track_id, mkvtoolnix_audio_id))
+                       "(mkvtoolnix ID {1})"
+                       .format(self.audio_track_id, mkvtoolnix_audio_id))
 
         try:
             temp_video_file = ("temp_video" +
@@ -514,22 +520,21 @@ class MKVFile():
         if (self.args.resume_previous and
                 os.path.isfile(temp_video_file) and
                 os.path.isfile(temp_audio_file)):
-
             self.log.debug("Temporary video and audio files already exist; "
                            "cancelling extract")
             temp_video_file = os.path.join(os.getcwd(), temp_video_file)
             temp_audio_file = os.path.join(os.getcwd(), temp_audio_file)
             os.chdir(prev_dir)
-            return (temp_video_file, temp_audio_file)
+            return temp_video_file, temp_audio_file
 
         # Remove any existing files with the same names
         if os.path.isfile(temp_video_file):
             self.log.debug("Deleting temporary video file {0}".format(
-                           os.path.join(os.getcwd(), temp_video_file)))
+                os.path.join(os.getcwd(), temp_video_file)))
             os.unlink(temp_video_file)
         if os.path.isfile(temp_audio_file):
             self.log.debug("Deleting temporary audio file {0}".format(
-                           os.path.join(os.getcwd(), temp_audio_file)))
+                os.path.join(os.getcwd(), temp_audio_file)))
             os.unlink(temp_audio_file)
 
         video_output = str(mkvtoolnix_video_id) + ":" + temp_video_file
@@ -542,8 +547,8 @@ class MKVFile():
 
         if process != 0:
             raise Exception("An error occurred while extracting tracks from {0}"
-                            " - please make sure this file exists and is readable".format(
-                            self.get_path()))
+                            " - please make sure this file exists and is readable"
+                            .format(self.get_path()))
 
         temp_video_file = os.path.join(os.getcwd(), temp_video_file)
         temp_audio_file = os.path.join(os.getcwd(), temp_audio_file)
@@ -555,4 +560,4 @@ class MKVFile():
             raise Exception("Audio or video file missing from "
                             "mkvextract output")
 
-        return (temp_video_file, temp_audio_file)
+        return temp_video_file, temp_audio_file
