@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 
 # XenonMKV: wrapper utility for MKV to MP4 container conversions
-# Jake Billo, jake@jakebillo.com
-# https://github.com/jbillo/xenonmkv
+# barisariburnu, barisariburnu@gmail.com
+# https://github.com/barisariburnu/xenonmkv
 
 import sys
 import os
+import re
 import ConfigParser
 
 
@@ -391,7 +392,8 @@ def main():
         log_exception("check_source_file", e)
 
     source_basename = os.path.basename(args.source_file)
-    source_noext = source_basename[0:source_basename.rindex(".")]
+    log.debug("SOURCE BASENAME: {0}".format(source_basename))
+    source_noext = source_basename
 
     if not args.name:
         args.name = source_noext
@@ -475,7 +477,7 @@ def main():
         # Once audio has been decoded to a WAV,
         # use the appropriate AAC encoder to transform it to .aac
         enc = AACEncoder(
-            os.path.join(args.scratch_dir, "audiodump.wav"), log, args)
+            args.scratch_dir, log, args)
         enc.encode()
         encoded_audio = os.path.join(args.scratch_dir, "audiodump.aac")
     else:
@@ -483,10 +485,9 @@ def main():
         # Reference the already-valid audio file and put it into the MP4 container.
         encoded_audio = audio_file
 
-    # Now, throw things back together into a .mp4 container with MP4Box.
+    # Now, throw things back together into a .mp4 container with Mp4Box.
     video_track = to_convert.get_video_track()
-    mp4box = MP4Box(video_file, encoded_audio, video_track.frame_rate,
-                    video_track.pixel_ar, args, log)
+    mp4box = MP4Box(video_file, encoded_audio, video_track.frame_rate, args, log)
     try:
         mp4box.package()
     except Exception as e:
@@ -496,7 +497,6 @@ def main():
 
     # Move the file to the destination directory with the original name
     dest_path = os.path.join(args.destination, source_noext + ".mp4")
-    shutil.move(os.path.join(args.scratch_dir, args.name + ".mp4"), dest_path)
 
     log.info("Processing of {0} complete; file saved as {1}".format(
              args.source_file, dest_path))
